@@ -230,12 +230,12 @@ def pull_dataset(dataset_slug: str):
         Slug of the dataset to which we perform the operation on
     """
     version = DatasetIdentifier.parse(dataset_slug).version or "latest"
-    client = _load_client(offline=False)
+    client = _load_client(offline=False, maybe_guest=True)
     try:
         dataset = client.get_remote_dataset(dataset_identifier=dataset_slug)
     except NotFound:
         _error(
-            f"Dataset '{dataset_slug}' does not exist at {client.url}. "
+            f"Dataset '{dataset_slug}' does not exist, please check the spelling. "
             f"Use 'darwin remote' to list all the remote datasets."
         )
     except Unauthenticated:
@@ -358,7 +358,7 @@ def split(dataset_slug: str, val_percentage: float, test_percentage: float, seed
 def list_remote_datasets(all_teams: bool, team: Optional[str] = None):
     """Lists remote datasets with its annotation progress"""
     # TODO: add listing open datasets
-    table = Table(["name", "images", "progress"], [Table.L, Table.R, Table.R])
+    table = Table(["name", "images"], [Table.L, Table.R])
     datasets = []
     if all_teams:
         for team in _config().get_all_teams():
@@ -369,13 +369,7 @@ def list_remote_datasets(all_teams: bool, team: Optional[str] = None):
         datasets = client.list_remote_datasets()
 
     for dataset in datasets:
-        table.add_row(
-            {
-                "name": f"{dataset.team}/{dataset.slug}",
-                "images": dataset.image_count,
-                "progress": f"{round(dataset.progress*100,1)}%",
-            }
-        )
+        table.add_row({"name": f"{dataset.team}/{dataset.slug}", "images": dataset.image_count})
     if len(table) == 0:
         print("No dataset available.")
     else:
@@ -517,7 +511,7 @@ def _config():
     return Config(Path.home() / ".darwin" / "config.yaml")
 
 
-def _load_client(team: Optional[str] = None, offline: bool = False):
+def _load_client(team: Optional[str] = None, offline: bool = False, maybe_guest: bool = False):
     """Fetches a client, potentially offline
 
     Parameters
@@ -525,6 +519,8 @@ def _load_client(team: Optional[str] = None, offline: bool = False):
     offline : bool
         Flag for using an offline client
 
+    maybe_guest : bool
+        Flag to make a guest client, if config is missing 
     Returns
     -------
     Client
@@ -535,7 +531,10 @@ def _load_client(team: Optional[str] = None, offline: bool = False):
         client = Client.from_config(config_dir, team_slug=team)
         return client
     except MissingConfig:
-        _error("Authenticate first")
+        if maybe_guest:
+            return Client.from_guest()
+        else:
+            _error("Authenticate first")
     except InvalidLogin:
         _error("Please re-authenticate")
     except Unauthenticated:
