@@ -95,6 +95,13 @@ class Options(object):
         parser_export.add_argument("dataset", type=str, help="Remote dataset name to export.")
         parser_export.add_argument("name", type=str, help="Name with with the version gets tagged.")
         parser_export.add_argument("annotation_class", type=str, nargs="?", help="List of class filters")
+        parser_export.add_argument(
+            "--include-url-token",
+            default=False,
+            action="store_true",
+            help="Each annotation file includes a url with an access token."
+            "Warning, anyone with the url can access the images, even without being a team member",
+        )
 
         # Releases
         parser_dataset_version = dataset_action.add_parser("releases", help="Available version of a dataset.")
